import os
import sys

from alibabacloud_iot20180120.client import Client as Iot20180120Client
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_iot20180120 import models as iot_20180120_models
from alibabacloud_tea_util import models as util_models
from alibabacloud_tea_util.client import Client as UtilClient

def create_client(access_key_id, access_key_secret, endpoint):
    config = open_api_models.Config(access_key_id=access_key_id, access_key_secret=access_key_secret)
    config.endpoint = endpoint
    return Iot20180120Client(config)

def get_snapshot_api(access_key_id, access_key_secret, endpoint, iot_instance_id, product_key, device_name):
    client = create_client(access_key_id=access_key_id, access_key_secret=access_key_secret, endpoint=endpoint)
    query_device_property_status_request = iot_20180120_models.QueryDevicePropertyStatusRequest()
    query_device_property_status_request.iot_instance_id = iot_instance_id
    query_device_property_status_request.product_key = product_key
    query_device_property_status_request.device_name = device_name

    runtime = util_models.RuntimeOptions()

    try:
        return client.query_device_property_status_with_options(query_device_property_status_request, runtime)
    except Exception as error:
        UtilClient.assert_as_string(error.message)

def get_snapshot_topic_api(access_key_id, access_key_secret, endpoint, iot_instance_id, product_key, device_name, asc, page_size, user_topic):
    client = create_client(access_key_id=access_key_id, access_key_secret=access_key_secret, endpoint=endpoint)
    query_devices_hot_storage_data_status_request = iot_20180120_models.QueryDevicesHotStorageDataStatusRequest()
    query_devices_hot_storage_data_status_request.iot_instance_id = iot_instance_id
    query_devices_hot_storage_data_status_request.product_key = product_key
    query_devices_hot_storage_data_status_request.device_name = device_name
    query_devices_hot_storage_data_status_request.asc = asc
    query_devices_hot_storage_data_status_request.page_size = page_size
    query_devices_hot_storage_data_status_request.user_topic = user_topic

    runtime = util_models.RuntimeOptions()

    try:
        return client.query_devices_hot_storage_data_status_with_options(query_devices_hot_storage_data_status_request, runtime)
    except Exception as error:
        UtilClient.assert_as_string(error.message)

def get_custom_snapshot_api(access_key_id, access_key_secret, endpoint, iot_instance_id, table_name):
    client = create_client(access_key_id=access_key_id, access_key_secret=access_key_secret, endpoint=endpoint)
    query_custom_timeline_table_status_request = iot_20180120_models.QueryCustomTimelineTableStatusRequest()
    query_custom_timeline_table_status_request.iot_instance_id = iot_instance_id
    query_custom_timeline_table_status_request.table_name = table_name

    runtime = util_models.RuntimeOptions()

    try:
        return client.query_custom_timeline_table_status_with_options(query_custom_timeline_table_status_request, runtime)
    except Exception as error:
        UtilClient.assert_as_string(error.message)
